.. Copyright 2014-2023 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Preparing for installation on Ubuntu
====================================

1. Python and basic development tools

   .. code-block:: bash

      sudo apt-get install python3 python3-venv


